@@ -285,6 +285,8 @@ static void usage(void)
     fputs("usage:\n"
 	  "\n"
 	  "      integrit -C conffile [-x] [-u] [-c]\n"
+	  "      integrit -V\n"
+	  "      integrit -h\n"
 	  "\n"
 	  "options:\n"
 	  "\n"
@@ -292,6 +294,7 @@ static void usage(void)
 	  "      -x	use XML output instead of abbreviated output\n"
 	  "      -u	do update: create current state database\n"
 	  "      -c	do check: verify current state against known db\n"
+	  "      -V	show integrit version info and exit\n"
 	  "      -h	show this help      \n\n", stderr);
 }
 
@@ -307,7 +310,7 @@ void parse_args(options *o, int argc, char *argv[])
 	  exit(EXIT_SUCCESS);
 	  break;
 	case 'V':
-	  puts(INTEGRIT_VERSION);
+	  puts(PROGNAME " version " INTEGRIT_VERSION);
 	  exit(EXIT_SUCCESS);
 	  break;
 	case 'v':
